"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.createGzipCompression = void 0;
var _CompressionPlugin = require("./definition/CompressionPlugin");
var _gzip = require("@webiny/utils/compression/gzip");
const GZIP = "gzip";
const TO_STORAGE_ENCODING = "base64";
const FROM_STORAGE_ENCODING = "utf8";
const convertToBuffer = value => {
  if (typeof value === "string") {
    return Buffer.from(value, TO_STORAGE_ENCODING);
  }
  return value;
};
class GzipCompression extends _CompressionPlugin.CompressionPlugin {
  canCompress(data) {
    /**
     * If already compressed, skip this.
     */
    if (data.compression) {
      if (data.compression !== "GZIP") {
        console.log(`Data is already compressed with "${data.compression}".`);
      }
      return false;
    }
    return true;
  }
  async compress(data) {
    const value = await (0, _gzip.compress)(JSON.stringify(data));
    return {
      compression: GZIP,
      value: value.toString(TO_STORAGE_ENCODING)
    };
  }
  canDecompress(data) {
    if (!data || !data.compression) {
      return false;
    } else if (data.compression !== GZIP) {
      console.log(`Could not decompress given data since its compression is not "${GZIP}". It is "${data.compression}".`);
      return false;
    }
    return true;
  }
  async decompress(data) {
    try {
      const buf = await (0, _gzip.decompress)(convertToBuffer(data.value));
      const value = buf.toString(FROM_STORAGE_ENCODING);
      return JSON.parse(value);
    } catch (ex) {
      return null;
    }
  }
}
const createGzipCompression = () => {
  return new GzipCompression();
};
/**
 * Left due to backward compatibility with older systems.
 * Remove when upgraded the system to run from @webiny/api-serverless-cms-aws
 */
exports.createGzipCompression = createGzipCompression;
var _default = () => {
  return createGzipCompression();
};
exports.default = _default;

//# sourceMappingURL=GzipCompression.js.map